package net.wanji.opt.controllerv2.report.design;

import com.alibaba.fastjson.JSON;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.ParentResult;

import java.util.ArrayList;
import java.util.List;

@Data
public class CrossRunStateAnalysisResult extends ParentResult {

    private CrossRunStateAnalysisResultResponse content;

    public CrossRunStateAnalysisResultResponse getContent() {
        return content;
    }

    public CrossRunStateAnalysisResult setContent(CrossRunStateAnalysisResultResponse content) {
        this.content = content;
        return this;
    }

    @Override
    public String toString() {
        return JSON.toJSONString(this);
    }

}

@Data
class CrossRunStateAnalysisResultResponse {


    @ApiModelProperty(value = "区域周最大流量路口名称", example = "经十路（舜耕路-山大路）")
    private String maxFlowCrossName;

    @ApiModelProperty(value = "区域周交通指数最大路口名称", example = "经十路（舜耕路-山大路）")
    private String maxTrafficIndexCrossName;

    @ApiModelProperty(value = "工作日平均流量", example = "13459899辆")
    private String workDayAvgFlow;

    @ApiModelProperty(value = "工作日早高峰最大小时流量", example = "300辆")
    private String workDayAmPeakMaxHourFlow;

    @ApiModelProperty(value = "工作日晚高峰最大小时流量", example = "300辆")
    private String workDayPmPeakMaxHourFlow;

    @ApiModelProperty(value = "工作日平峰最大小时流量", example = "300辆")
    private String workDayFmPeakMaxHourFlow;

    @ApiModelProperty(value = "周末全天平均流量", example = "提升10%")
    private String weekEndAvgFlow;

    @ApiModelProperty(value = "工作日早高峰平均交通指数", example = "4.5")
    private String workDayAmPeakAvgTrafficIndex;

    @ApiModelProperty(value = "工作日晚高峰平均交通指数", example = "5.5")
    private String workDayPmPeakAvgTrafficIndex;

    //========================================================================
    @ApiModelProperty(value = "工作日平均流量与上周比较情况", example = "13459899辆")
    private String avgFlowLastWeekCompare;

    @ApiModelProperty(value = "工作日早高峰最大小时流量与上周比较情况", example = "300辆")
    private String amPeakMaxHourFlowLastWeekCompare;

    @ApiModelProperty(value = "工作日晚高峰最大小时流量与上周比较情况", example = "300辆")
    private String pmPeakMaxHourFlowLastWeekCompare;

    @ApiModelProperty(value = "工作日平峰最大小时流量与上周比较情况", example = "300辆")
    private String fmPeakMaxHourFlowLastWeekCompare;

    @ApiModelProperty(value = "周末全天平均流量与上周比较情况", example = "提升10%")
    private String endAvgFlowLastWeekCompare;

    @ApiModelProperty(value = "工作日早高峰平均交通指数与上周比较情况", example = "4.5")
    private String amPeakAvgTrafficIndexLastWeekCompare;

    @ApiModelProperty(value = "工作日晚高峰平均交通指数与上周比较情况", example = "5.5")
    private String pmPeakAvgTrafficIndexLastWeekCompare;

    //================================================================================================//

    private List<CrossRunStateDetailAnalysisData> dataList = new ArrayList<>();

}

@Data
class CrossRunStateDetailAnalysisData {

    @ApiModelProperty(value = "路口名称", example = "经十路（舜耕路-山大路）")
    private String crossName;

    @ApiModelProperty(value = "本周高峰最大小时流量", example = "8900")
    private Integer thisWeekPeakMaxFlow;

    @ApiModelProperty(value = "上周周末最大小时流量", example = "8900")
    private Integer lastWeekPeakMaxFlow;

    @ApiModelProperty(value = "本周周末最大小时流量", example = "8900")
    private Integer thisWeekEndMaxFlow;

    @ApiModelProperty(value = "上周周末最大小时流量", example = "8900")
    private Integer lastWeekEndMaxFlow;

    @ApiModelProperty(value = "本周工作日早高峰交通指数", example = "8900")
    private Integer thisWeekWorkDayTrafficIndex;

    @ApiModelProperty(value = "上周周工作日早高峰交通指数", example = "8900")
    private Integer lastWeekWorkDayTrafficIndex;

}



